/**
 * Copyright 2019-2021 Britanicus <marcusbritanicus@gmail.com>
 *
 * This file is a part of DesQ Shell (https://gitlab.com/DesQ/Shell)
 * DesQ Shell is the main Shell UI of the DesQ Project
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * at your option, any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 **/

#include "DesQContainer.hpp"
#include "DesQWidget.hpp"

#include <desq/Utils.hpp>
#include <desq/desq-config.h>

// DesQ Headers
#include <desqui/ShellPlugin.hpp>

DesQContainer::DesQContainer( QStringList widgets ) {
    mWidgets << widgets;

    /* Title */
    setWindowTitle( "DesQShell | Widgets" );
    setToolTip( "Desktop Widgets of DesQ Shell" );

    /* No frame, and stay at bottom */
    Qt::WindowFlags wFlags = Qt::FramelessWindowHint | Qt::WindowStaysOnBottomHint | Qt::BypassWindowManagerHint;

    /* Set the windowFlags */
    setWindowFlags( wFlags );

    setAttribute( Qt::WA_TranslucentBackground );

    setFixedWidth( 200 );
    setFixedHeight( qApp->primaryScreen()->size().height() );

    QTimer::singleShot( 100, this, &DesQContainer::startLayout );
}


void DesQContainer::startLayout() {
    QVBoxLayout *lyt = new QVBoxLayout();

    lyt->setContentsMargins( 0, 10, 0, 10 );
    lyt->setSpacing( 10 );

    for ( QString widget: mWidgets ) {
        DesQWidget *w = new DesQWidget( widget );
        lyt->addWidget( w );
    }

    lyt->addStretch();

    setLayout( lyt );
}
